@@ -6,20 +6,33 @@ use warnings;
 
 use Carp;
 use Module::Runtime qw(use_module);
-use Params::Get;
+use Params::Get 0.11;
 use Text::Capitalize 'capitalize_title';
 
+=encoding utf-8
+
 =head1 NAME
 
 Geo::Address::Parser - Lightweight country-aware address parser from flat text
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
+
+# Supported countries and their corresponding rule modules
+my %COUNTRY_MODULE = (
+	US => 'Geo::Address::Parser::Rules::US',
+	UK => 'Geo::Address::Parser::Rules::UK',
+	CA => 'Geo::Address::Parser::Rules::CA',
+	AU => 'Geo::Address::Parser::Rules::AU',
+	NZ => 'Geo::Address::Parser::Rules::NZ',
+);
+
+=head1 METHODS
 
 =head1 SYNOPSIS
 
@@ -35,41 +48,26 @@ This module extracts address components from flat text input. It supports
 lightweight parsing for the US, UK, Canada, Australia, and New Zealand, using
 country-specific regular expressions.
 
-=head1 METHODS
-
 =head2 new(country => $code)
 
 Creates a new parser for a specific country (US, UK, CA, AU, NZ).
 
-=head2 parse($text)
+=head3 FORMAL SPECIFICATION
 
-Parses a flat string and returns a hashref with the following fields:
+    [COUNTRY]
 
-=over
+    GeoAddressParserNew
+    ====================
+    country? : COUNTRY
+    supported : ℙ COUNTRY
+    parser! : Parser
 
-=item * name
-
-=item * street
-
-=item * city
-
-=item * region
-
-=item * country
-
-=back
+    supported = {US, UK, CA, AU, NZ}
+    country? ∈ supported
+    parser! = parserFor(country?)
 
 =cut
 
-# Supported countries and their corresponding rule modules
-my %COUNTRY_MODULE = (
-	US => 'Geo::Address::Parser::Rules::US',
-	UK => 'Geo::Address::Parser::Rules::UK',
-	CA => 'Geo::Address::Parser::Rules::CA',
-	AU => 'Geo::Address::Parser::Rules::AU',
-	NZ => 'Geo::Address::Parser::Rules::NZ',
-);
-
 sub new {
 	my $class = shift;
 
@@ -89,6 +87,46 @@ sub new {
 	}, $class;
 }
 
+=head2 parse($text)
+
+Parses a flat string and returns a hashref with the following fields:
+
+=over
+
+=item * name
+
+=item * street
+
+=item * city
+
+=item * region
+
+=item * country
+
+=back
+
+=head3 FORMAL SPECIFICATION
+
+    [TEXT, COUNTRY, FIELD, VALUE]
+
+    GeoAddressParserState
+    ======================
+    country : COUNTRY
+    parser : COUNTRY ↛ (TEXT ↛ FIELD ↛ VALUE)
+
+    GeoAddressParserParse
+    ======================
+    ΔGeoAddressParserState
+    text? : TEXT
+    result! : FIELD ↛ VALUE
+
+    text? ≠ ∅
+    country ∈ dom parser
+    result! = (parser(country))(text?)
+    result!("country") = country
+
+=cut
+
 sub parse
 {
 	my $self = shift;
